@@ -4,11 +4,11 @@ use strict;
 use warnings;
 use 5.008001;
 use base 'Exporter';
-use POSIX;
+use POSIX ();
 use Date::Parse;
 
 # ABSTRACT: Fills in string templates from hash of fields
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 
 our @EXPORT = qw(expand_string missing_values expand_stringi);
@@ -19,9 +19,9 @@ my %special =
 (
     '%' => sub { sprintf("%$_[0]", $_[1]) },
 
-    ':' => sub { strftime($_[0], localtime(str2time($_[1]))) },
+    ':' => sub { POSIX::strftime($_[0], localtime(str2time($_[1]))) },
 
-    '!' => sub { strftime($_[0], gmtime(str2time($_[1]))) },
+    '!' => sub { POSIX::strftime($_[0], gmtime(str2time($_[1]))) },
 
     '#' => sub { my @args = split(/\s*,\s*/, $_[0]);
                  defined $args[1]
@@ -111,13 +111,13 @@ sub expand_hash
     my $missing = 1;
 
     while ($changeflag)
-    {    
+    {
         $changeflag = 0;
         $missing = 0;
         foreach my $key (sort keys %$hash)
         {
             my $newstr = expand_string($hash->{$key}, $hash, 1);
-            
+
             if ($newstr ne $hash->{$key})
             {
                 $hash->{$key} = $newstr;
@@ -144,7 +144,7 @@ String::Template - Fills in string templates from hash of fields
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -161,37 +161,40 @@ version 0.21
 
 Generate strings based on a template.
 
-=head1 FUNCTIONS
+=head2 template language
 
-=head2 expand_string
+Replacement tokens are denoted with angle brackets.  That is C<< <fieldname> >>
+is replaced by the values in the C<< \%fields >> hash reference provided.
 
- my $str = expand_string($template, \%fields, $undef_flag);
-
-Fills in a simple template with values from a hash, replacing tokens
-like "<fieldname>" with the value from the hash $fields->{fieldname}.
-
-Some special characters can be used to impose formatting on the
+Some special characters can be used after the field name to impose formatting on the
 fields:
 
- % - treat like a sprintf() format
-     e.g.  <int%02d>
+=over 4
 
- : - treat like a L<POSIX::strftime()> format
-     e.g. <date:%Y-%m-%d>
+=item C<%>
 
- ! - Just like ':', but with gmtime instead of localtime
-     e.g. <gmdate!%Y-%m-%d %H:%M>
+Treat like a L<sprintf|perlfunc/sprintf> format, example: C<< <int%02d> >>.
 
- # - treat like args to substr()
-     e.g. <str#0,2> or <str#4>
+=item C<:>
 
-For the ':' strftime formats, the field is parsed by L<Date::Parse>,
-so it can handle any format that can handle.
+Treat like a L<POSIX/strftime> format, example C<< <date:%Y-%m-%d> >>.
 
-Handling of undefined fields can be controlled with $undef_flag.  If
-it is false (default), undefined fields are simply replace with an
-empty string.  If set to true, the field is kept verbatim.  This can
-be useful for multiple expansion passes.
+The field is parsed by L<Date::Parse>, so it can handle any format that it
+can handle.
+
+=item C<!>
+
+[version 0.05]
+
+Same as C<:>, but with L<gmtime|perlfunc/gmtime> instead of L<localtime|perlfunc/localtime>.
+
+=item C<#>
+
+Treat like args to L<substr|perlfunc/substr>; example C<< <str#0,2> >> or C<< <str#4> >>.
+
+=item C<{> and C<}>
+
+[version 0.20]
 
 The C<{> character is specially special, since it allows fields to
 contain additional characters that are not intended for formatting.
@@ -202,40 +205,70 @@ replaced with the empty string.
 This makes it possible to have templates like this:
 
  my $template = '<name><nick{ "%s"}><surname{ %s}>';
-
+ 
  my $mack = { name => 'Mack', nick    => 'The Knife' };
  my $jack = { name => 'Jack', surname => 'Sheppard'  };
-
+ 
  expand_string( $template, $mack ); # Returns 'Mack "The Knife"'
  expand_string( $template, $jack ); # Returns 'Jack Sheppard'
 
+=back
+
+=head1 FUNCTIONS
+
+All functions are exported by default, or by request, except for L</expand_hash>
+
+=head2 expand_string
+
+ my $str = expand_string($template, \%fields);
+ my $str = expand_string($template, \%fields, $undef_flag);
+
+Fills in a simple template with values from a hash, replacing tokens
+with the value from the hash C<< $fields{fieldname} >>.
+
+Handling of undefined fields can be controlled with C<$undef_flag>.  If
+it is false (default), undefined fields are simply replaced with an
+empty string.  If set to true, the field is kept verbatim.  This can
+be useful for multiple expansion passes.
+
 =head2 expand_stringi
 
+[version 0.08]
+
+ my $str = expand_stringi($template, \%fields);
  my $str = expand_stringi($template, \%fields, $undef_flag);
 
-expand_stringi works just like expand_string, except that tokens
+C<expand_stringi> works just like L</expand_string>, except that tokens
 and hash keys are treated case insensitively.
 
 =head2 missing_values
 
+[version 0.06]
+
+ my @missing = missing_values($template, \%fields);
  my @missing = missing_values($template, \%fields, $dont_allow_undefs);
 
 Checks to see if the template variables in a string template exist
-in a hash.  Set $dont_allow_undefs to 1 to also check to see if the
+in a hash.  Set C<$dont_allow_undefs> to 1 to also check to see if the
 values for all such keys are defined.
 
 Returns a list of missing keys or an empty list if no keys were missing.
 
 =head2 expand_hash
 
- my $status = expand_hash($hash[, $maxdepth]);
+[version 0.07]
+
+ my $status = expand_hash($hash);
+ my $status = expand_hash($hash, $maxdepth);
 
 Expand a hash of templates/values.  This function will repeatedly
 replace templates in the values of the hash with the values of the
-hash they reference, until either all "<>" templates are gone, or
-it has iterated $maxdepth times (default 10).
+hash they reference, until either all C<< <fieldname> >> templates are gone, or
+it has iterated C<$maxdepth> times (default 10).
 
-Returns undef if there are unexpanded templates left, otherwise true.
+Returns C<undef> if there are unexpanded templates left, otherwise true.
+
+This function must be explicitly exported.
 
 =head1 SEE ALSO
 
